// Written in the D programming language

/**
 * Contains listing of named entities for the D lexer.
 *
 * Copyright: Brian Schott 2013
 * License: <a href="http://www.boost.org/LICENSE_1_0.txt">Boost License 1.0</a>.
 * Authors: Brian Schott
 * Source: $(PHOBOSSRC std/d/_lexer.d)
 */

module std.d.entities;

/**
 * Generated from $(LINK http://www.w3.org/TR/html5/entities.json)
 * Standards: $(LINK http://www.w3.org/TR/html5/syntax.html#named-character-references)
 */
immutable string[string] characterEntities;

static this()
{
	characterEntities = [
		"Aacute": "\u00C1",
		"aacute": "\u00E1",
		"Abreve": "\u0102",
		"abreve": "\u0103",
		"acd": "\u223F",
		"acE": x"223E0333",
		"Acirc": "\u00C2",
		"acirc": "\u00E2",
		"ac": "\u223E",
		"acute": "\u00B4",
		"Acy": "\u0410",
		"acy": "\u0430",
		"AElig": "\u00C6",
		"aelig": "\u00E6",
		"Afr": x"D835DD04",
		"afr": x"D835DD1E",
		"af": "\u2061",
		"Agrave": "\u00C0",
		"agrave": "\u00E0",
		"alefsym": "\u2135",
		"aleph": "\u2135",
		"Alpha": "\u0391",
		"alpha": "\u03B1",
		"Amacr": "\u0100",
		"amacr": "\u0101",
		"amalg": "\u2A3F",
		"amp": "\u0026",
		"AMP": "\u0026",
		"andand": "\u2A55",
		"andd": "\u2A5C",
		"andslope": "\u2A58",
		"and": "\u2227",
		"And": "\u2A53",
		"andv": "\u2A5A",
		"ange": "\u29A4",
		"angle": "\u2220",
		"angmsdaa": "\u29A8",
		"angmsdab": "\u29A9",
		"angmsdac": "\u29AA",
		"angmsdad": "\u29AB",
		"angmsdae": "\u29AC",
		"angmsdaf": "\u29AD",
		"angmsdag": "\u29AE",
		"angmsdah": "\u29AF",
		"angmsd": "\u2221",
		"angrt": "\u221F",
		"angrtvbd": "\u299D",
		"angrtvb": "\u22BE",
		"angsph": "\u2222",
		"angst": "\u00C5",
		"ang": "\u2220",
		"angzarr": "\u237C",
		"Aogon": "\u0104",
		"aogon": "\u0105",
		"Aopf": x"D835DD38",
		"aopf": x"D835DD52",
		"apacir": "\u2A6F",
		"ape": "\u224A",
		"apE": "\u2A70",
		"apid": "\u224B",
		"apos": "\u0027",
		"ApplyFunction": "\u2061",
		"approxeq": "\u224A",
		"approx": "\u2248",
		"ap": "\u2248",
		"Aring": "\u00C5",
		"aring": "\u00E5",
		"Ascr": x"D835DC9C",
		"ascr": x"D835DCB6",
		"Assign": "\u2254",
		"ast": "\u002A",
		"asympeq": "\u224D",
		"asymp": "\u2248",
		"Atilde": "\u00C3",
		"atilde": "\u00E3",
		"Auml": "\u00C4",
		"auml": "\u00E4",
		"awconint": "\u2233",
		"awint": "\u2A11",
		"backcong": "\u224C",
		"backepsilon": "\u03F6",
		"backprime": "\u2035",
		"backsimeq": "\u22CD",
		"backsim": "\u223D",
		"Backslash": "\u2216",
		"barvee": "\u22BD",
		"Barv": "\u2AE7",
		"barwedge": "\u2305",
		"barwed": "\u2305",
		"Barwed": "\u2306",
		"bbrktbrk": "\u23B6",
		"bbrk": "\u23B5",
		"bcong": "\u224C",
		"Bcy": "\u0411",
		"bcy": "\u0431",
		"bdquo": "\u201E",
		"because": "\u2235",
		"Because": "\u2235",
		"becaus": "\u2235",
		"bemptyv": "\u29B0",
		"bepsi": "\u03F6",
		"Bernoullis": "\u212C",
		"bernou": "\u212C",
		"Beta": "\u0392",
		"beta": "\u03B2",
		"beth": "\u2136",
		"between": "\u226C",
		"Bfr": x"D835DD05",
		"bfr": x"D835DD1F",
		"bigcap": "\u22C2",
		"bigcirc": "\u25EF",
		"bigcup": "\u22C3",
		"bigodot": "\u2A00",
		"bigoplus": "\u2A01",
		"bigotimes": "\u2A02",
		"bigsqcup": "\u2A06",
		"bigstar": "\u2605",
		"bigtriangledown": "\u25BD",
		"bigtriangleup": "\u25B3",
		"biguplus": "\u2A04",
		"bigvee": "\u22C1",
		"bigwedge": "\u22C0",
		"bkarow": "\u290D",
		"blacklozenge": "\u29EB",
		"blacksquare": "\u25AA",
		"blacktriangledown": "\u25BE",
		"blacktriangleleft": "\u25C2",
		"blacktriangleright": "\u25B8",
		"blacktriangle": "\u25B4",
		"blank": "\u2423",
		"blk12": "\u2592",
		"blk14": "\u2591",
		"blk34": "\u2593",
		"block": "\u2588",
		"bnequiv": x"226120E5",
		"bne": x"003D20E5",
		"bnot": "\u2310",
		"bNot": "\u2AED",
		"Bopf": x"D835DD39",
		"bopf": x"D835DD53",
		"bottom": "\u22A5",
		"bot": "\u22A5",
		"bowtie": "\u22C8",
		"boxbox": "\u29C9",
		"boxdl": "\u2510",
		"boxdL": "\u2555",
		"boxDl": "\u2556",
		"boxDL": "\u2557",
		"boxdr": "\u250C",
		"boxdR": "\u2552",
		"boxDr": "\u2553",
		"boxDR": "\u2554",
		"boxhd": "\u252C",
		"boxHd": "\u2564",
		"boxhD": "\u2565",
		"boxHD": "\u2566",
		"boxh": "\u2500",
		"boxH": "\u2550",
		"boxhu": "\u2534",
		"boxHu": "\u2567",
		"boxhU": "\u2568",
		"boxHU": "\u2569",
		"boxminus": "\u229F",
		"boxplus": "\u229E",
		"boxtimes": "\u22A0",
		"boxul": "\u2518",
		"boxuL": "\u255B",
		"boxUl": "\u255C",
		"boxUL": "\u255D",
		"boxur": "\u2514",
		"boxuR": "\u2558",
		"boxUr": "\u2559",
		"boxUR": "\u255A",
		"boxvh": "\u253C",
		"boxvH": "\u256A",
		"boxVh": "\u256B",
		"boxVH": "\u256C",
		"boxvl": "\u2524",
		"boxvL": "\u2561",
		"boxVl": "\u2562",
		"boxVL": "\u2563",
		"boxvr": "\u251C",
		"boxvR": "\u255E",
		"boxVr": "\u255F",
		"boxVR": "\u2560",
		"boxv": "\u2502",
		"boxV": "\u2551",
		"bprime": "\u2035",
		"breve": "\u02D8",
		"Breve": "\u02D8",
		"brvbar": "\u00A6",
		"Bscr": "\u212C",
		"bscr": x"D835DCB7",
		"bsemi": "\u204F",
		"bsime": "\u22CD",
		"bsim": "\u223D",
		"bsolb": "\u29C5",
		"bsolhsub": "\u27C8",
		"bsol": "\u005C",
		"bullet": "\u2022",
		"bull": "\u2022",
		"Bumpeq": "\u224E",
		"bumpeq": "\u224F",
		"bumpe": "\u224F",
		"bumpE": "\u2AAE",
		"bump": "\u224E",
		"Cacute": "\u0106",
		"cacute": "\u0107",
		"capand": "\u2A44",
		"capbrcup": "\u2A49",
		"capcap": "\u2A4B",
		"capcup": "\u2A47",
		"capdot": "\u2A40",
		"CapitalDifferentialD": "\u2145",
		"caps": x"2229FE00",
		"cap": "\u2229",
		"Cap": "\u22D2",
		"caret": "\u2041",
		"caron": "\u02C7",
		"Cayleys": "\u212D",
		"ccaps": "\u2A4D",
		"Ccaron": "\u010C",
		"ccaron": "\u010D",
		"Ccedil": "\u00C7",
		"ccedil": "\u00E7",
		"Ccirc": "\u0108",
		"ccirc": "\u0109",
		"Cconint": "\u2230",
		"ccupssm": "\u2A50",
		"ccups": "\u2A4C",
		"Cdot": "\u010A",
		"cdot": "\u010B",
		"Cedilla": "\u00B8",
		"cedil": "\u00B8",
		"cemptyv": "\u29B2",
		"centerdot": "\u00B7",
		"CenterDot": "\u00B7",
		"cent": "\u00A2",
		"Cfr": "\u212D",
		"cfr": x"D835DD20",
		"CHcy": "\u0427",
		"chcy": "\u0447",
		"checkmark": "\u2713",
		"check": "\u2713",
		"Chi": "\u03A7",
		"chi": "\u03C7",
		"circeq": "\u2257",
		"circlearrowleft": "\u21BA",
		"circlearrowright": "\u21BB",
		"circledast": "\u229B",
		"circledcirc": "\u229A",
		"circleddash": "\u229D",
		"CircleDot": "\u2299",
		"circledR": "\u00AE",
		"circledS": "\u24C8",
		"CircleMinus": "\u2296",
		"CirclePlus": "\u2295",
		"CircleTimes": "\u2297",
		"circ": "\u02C6",
		"cire": "\u2257",
		"cirE": "\u29C3",
		"cirfnint": "\u2A10",
		"cirmid": "\u2AEF",
		"cirscir": "\u29C2",
		"cir": "\u25CB",
		"ClockwiseContourIntegral": "\u2232",
		"CloseCurlyDoubleQuote": "\u201D",
		"CloseCurlyQuote": "\u2019",
		"clubs": "\u2663",
		"clubsuit": "\u2663",
		"coloneq": "\u2254",
		"colone": "\u2254",
		"Colone": "\u2A74",
		"colon": "\u003A",
		"Colon": "\u2237",
		"commat": "\u0040",
		"comma": "\u002C",
		"compfn": "\u2218",
		"complement": "\u2201",
		"complexes": "\u2102",
		"comp": "\u2201",
		"congdot": "\u2A6D",
		"Congruent": "\u2261",
		"cong": "\u2245",
		"conint": "\u222E",
		"Conint": "\u222F",
		"ContourIntegral": "\u222E",
		"Copf": "\u2102",
		"copf": x"D835DD54",
		"coprod": "\u2210",
		"Coproduct": "\u2210",
		"copysr": "\u2117",
		"copy": "\u00A9",
		"COPY": "\u00A9",
		"CounterClockwiseContourIntegral": "\u2233",
		"crarr": "\u21B5",
		"cross": "\u2717",
		"Cross": "\u2A2F",
		"Cscr": x"D835DC9E",
		"cscr": x"D835DCB8",
		"csube": "\u2AD1",
		"csub": "\u2ACF",
		"csupe": "\u2AD2",
		"csup": "\u2AD0",
		"ctdot": "\u22EF",
		"cudarrl": "\u2938",
		"cudarrr": "\u2935",
		"cuepr": "\u22DE",
		"cuesc": "\u22DF",
		"cularrp": "\u293D",
		"cularr": "\u21B6",
		"cupbrcap": "\u2A48",
		"CupCap": "\u224D",
		"cupcap": "\u2A46",
		"cupcup": "\u2A4A",
		"cupdot": "\u228D",
		"cupor": "\u2A45",
		"cups": x"222AFE00",
		"cup": "\u222A",
		"Cup": "\u22D3",
		"curarrm": "\u293C",
		"curarr": "\u21B7",
		"curlyeqprec": "\u22DE",
		"curlyeqsucc": "\u22DF",
		"curlyvee": "\u22CE",
		"curlywedge": "\u22CF",
		"curren": "\u00A4",
		"curvearrowleft": "\u21B6",
		"curvearrowright": "\u21B7",
		"cuvee": "\u22CE",
		"cuwed": "\u22CF",
		"cwconint": "\u2232",
		"cwint": "\u2231",
		"cylcty": "\u232D",
		"dagger": "\u2020",
		"Dagger": "\u2021",
		"daleth": "\u2138",
		"darr": "\u2193",
		"Darr": "\u21A1",
		"dArr": "\u21D3",
		"dash": "\u2010",
		"dashv": "\u22A3",
		"Dashv": "\u2AE4",
		"dbkarow": "\u290F",
		"dblac": "\u02DD",
		"Dcaron": "\u010E",
		"dcaron": "\u010F",
		"Dcy": "\u0414",
		"dcy": "\u0434",
		"ddagger": "\u2021",
		"ddarr": "\u21CA",
		"DDotrahd": "\u2911",
		"ddotseq": "\u2A77",
		"DD": "\u2145",
		"dd": "\u2146",
		"deg": "\u00B0",
		"Delta": "\u0394",
		"delta": "\u03B4",
		"Del": "\u2207",
		"demptyv": "\u29B1",
		"dfisht": "\u297F",
		"Dfr": x"D835DD07",
		"dfr": x"D835DD21",
		"dharl": "\u21C3",
		"dharr": "\u21C2",
		"dHar": "\u2965",
		"DiacriticalAcute": "\u00B4",
		"DiacriticalDot": "\u02D9",
		"DiacriticalDoubleAcute": "\u02DD",
		"DiacriticalGrave": "\u0060",
		"DiacriticalTilde": "\u02DC",
		"diamondsuit": "\u2666",
		"diamond": "\u22C4",
		"Diamond": "\u22C4",
		"diams": "\u2666",
		"diam": "\u22C4",
		"die": "\u00A8",
		"DifferentialD": "\u2146",
		"digamma": "\u03DD",
		"disin": "\u22F2",
		"divideontimes": "\u22C7",
		"divide": "\u00F7",
		"divonx": "\u22C7",
		"div": "\u00F7",
		"DJcy": "\u0402",
		"djcy": "\u0452",
		"dlcorn": "\u231E",
		"dlcrop": "\u230D",
		"dollar": "\u0024",
		"Dopf": x"D835DD3B",
		"dopf": x"D835DD55",
		"DotDot": "\u20DC",
		"doteqdot": "\u2251",
		"doteq": "\u2250",
		"DotEqual": "\u2250",
		"dotminus": "\u2238",
		"dotplus": "\u2214",
		"dotsquare": "\u22A1",
		"Dot": "\u00A8",
		"dot": "\u02D9",
		"doublebarwedge": "\u2306",
		"DoubleContourIntegral": "\u222F",
		"DoubleDot": "\u00A8",
		"DoubleDownArrow": "\u21D3",
		"DoubleLeftArrow": "\u21D0",
		"DoubleLeftRightArrow": "\u21D4",
		"DoubleLeftTee": "\u2AE4",
		"DoubleLongLeftArrow": "\u27F8",
		"DoubleLongLeftRightArrow": "\u27FA",
		"DoubleLongRightArrow": "\u27F9",
		"DoubleRightArrow": "\u21D2",
		"DoubleRightTee": "\u22A8",
		"DoubleUpArrow": "\u21D1",
		"DoubleUpDownArrow": "\u21D5",
		"DoubleVerticalBar": "\u2225",
		"DownArrowBar": "\u2913",
		"downarrow": "\u2193",
		"DownArrow": "\u2193",
		"Downarrow": "\u21D3",
		"DownArrowUpArrow": "\u21F5",
		"DownBreve": "\u0311",
		"downdownarrows": "\u21CA",
		"downharpoonleft": "\u21C3",
		"downharpoonright": "\u21C2",
		"DownLeftRightVector": "\u2950",
		"DownLeftTeeVector": "\u295E",
		"DownLeftVectorBar": "\u2956",
		"DownLeftVector": "\u21BD",
		"DownRightTeeVector": "\u295F",
		"DownRightVectorBar": "\u2957",
		"DownRightVector": "\u21C1",
		"DownTeeArrow": "\u21A7",
		"DownTee": "\u22A4",
		"drbkarow": "\u2910",
		"drcorn": "\u231F",
		"drcrop": "\u230C",
		"Dscr": x"D835DC9F",
		"dscr": x"D835DCB9",
		"DScy": "\u0405",
		"dscy": "\u0455",
		"dsol": "\u29F6",
		"Dstrok": "\u0110",
		"dstrok": "\u0111",
		"dtdot": "\u22F1",
		"dtrif": "\u25BE",
		"dtri": "\u25BF",
		"duarr": "\u21F5",
		"duhar": "\u296F",
		"dwangle": "\u29A6",
		"DZcy": "\u040F",
		"dzcy": "\u045F",
		"dzigrarr": "\u27FF",
		"Eacute": "\u00C9",
		"eacute": "\u00E9",
		"easter": "\u2A6E",
		"Ecaron": "\u011A",
		"ecaron": "\u011B",
		"Ecirc": "\u00CA",
		"ecirc": "\u00EA",
		"ecir": "\u2256",
		"ecolon": "\u2255",
		"Ecy": "\u042D",
		"ecy": "\u044D",
		"eDDot": "\u2A77",
		"Edot": "\u0116",
		"edot": "\u0117",
		"eDot": "\u2251",
		"ee": "\u2147",
		"efDot": "\u2252",
		"Efr": x"D835DD08",
		"efr": x"D835DD22",
		"Egrave": "\u00C8",
		"egrave": "\u00E8",
		"egsdot": "\u2A98",
		"egs": "\u2A96",
		"eg": "\u2A9A",
		"Element": "\u2208",
		"elinters": "\u23E7",
		"ell": "\u2113",
		"elsdot": "\u2A97",
		"els": "\u2A95",
		"el": "\u2A99",
		"Emacr": "\u0112",
		"emacr": "\u0113",
		"emptyset": "\u2205",
		"EmptySmallSquare": "\u25FB",
		"empty": "\u2205",
		"EmptyVerySmallSquare": "\u25AB",
		"emptyv": "\u2205",
		"emsp13": "\u2004",
		"emsp14": "\u2005",
		"emsp": "\u2003",
		"ENG": "\u014A",
		"eng": "\u014B",
		"ensp": "\u2002",
		"Eogon": "\u0118",
		"eogon": "\u0119",
		"Eopf": x"D835DD3C",
		"eopf": x"D835DD56",
		"eparsl": "\u29E3",
		"epar": "\u22D5",
		"eplus": "\u2A71",
		"Epsilon": "\u0395",
		"epsilon": "\u03B5",
		"epsi": "\u03B5",
		"epsiv": "\u03F5",
		"eqcirc": "\u2256",
		"eqcolon": "\u2255",
		"eqsim": "\u2242",
		"eqslantgtr": "\u2A96",
		"eqslantless": "\u2A95",
		"equals": "\u003D",
		"EqualTilde": "\u2242",
		"Equal": "\u2A75",
		"equest": "\u225F",
		"Equilibrium": "\u21CC",
		"equivDD": "\u2A78",
		"equiv": "\u2261",
		"eqvparsl": "\u29E5",
		"erarr": "\u2971",
		"erDot": "\u2253",
		"escr": "\u212F",
		"Escr": "\u2130",
		"esdot": "\u2250",
		"esim": "\u2242",
		"Esim": "\u2A73",
		"Eta": "\u0397",
		"eta": "\u03B7",
		"ETH": "\u00D0",
		"eth": "\u00F0",
		"Euml": "\u00CB",
		"euml": "\u00EB",
		"euro": "\u20AC",
		"excl": "\u0021",
		"Exists": "\u2203",
		"exist": "\u2203",
		"expectation": "\u2130",
		"exponentiale": "\u2147",
		"ExponentialE": "\u2147",
		"fallingdotseq": "\u2252",
		"Fcy": "\u0424",
		"fcy": "\u0444",
		"female": "\u2640",
		"ffilig": "\uFB03",
		"fflig": "\uFB00",
		"ffllig": "\uFB04",
		"Ffr": x"D835DD09",
		"ffr": x"D835DD23",
		"filig": "\uFB01",
		"FilledSmallSquare": "\u25FC",
		"FilledVerySmallSquare": "\u25AA",
		"fjlig": x"0066006A",
		"flat": "\u266D",
		"fllig": "\uFB02",
		"fltns": "\u25B1",
		"fnof": "\u0192",
		"Fopf": x"D835DD3D",
		"fopf": x"D835DD57",
		"forall": "\u2200",
		"ForAll": "\u2200",
		"fork": "\u22D4",
		"forkv": "\u2AD9",
		"Fouriertrf": "\u2131",
		"fpartint": "\u2A0D",
		"frac12": "\u00BD",
		"frac13": "\u2153",
		"frac14": "\u00BC",
		"frac15": "\u2155",
		"frac16": "\u2159",
		"frac18": "\u215B",
		"frac23": "\u2154",
		"frac25": "\u2156",
		"frac34": "\u00BE",
		"frac35": "\u2157",
		"frac38": "\u215C",
		"frac45": "\u2158",
		"frac56": "\u215A",
		"frac58": "\u215D",
		"frac78": "\u215E",
		"frasl": "\u2044",
		"frown": "\u2322",
		"Fscr": "\u2131",
		"fscr": x"D835DCBB",
		"gacute": "\u01F5",
		"Gammad": "\u03DC",
		"gammad": "\u03DD",
		"Gamma": "\u0393",
		"gamma": "\u03B3",
		"gap": "\u2A86",
		"Gbreve": "\u011E",
		"gbreve": "\u011F",
		"Gcedil": "\u0122",
		"Gcirc": "\u011C",
		"gcirc": "\u011D",
		"Gcy": "\u0413",
		"gcy": "\u0433",
		"Gdot": "\u0120",
		"gdot": "\u0121",
		"gel": "\u22DB",
		"gEl": "\u2A8C",
		"geqq": "\u2267",
		"geqslant": "\u2A7E",
		"geq": "\u2265",
		"gescc": "\u2AA9",
		"gesdotol": "\u2A84",
		"gesdoto": "\u2A82",
		"gesdot": "\u2A80",
		"gesles": "\u2A94",
		"gesl": x"22DBFE00",
		"ges": "\u2A7E",
		"ge": "\u2265",
		"gE": "\u2267",
		"Gfr": x"D835DD0A",
		"gfr": x"D835DD24",
		"ggg": "\u22D9",
		"gg": "\u226B",
		"Gg": "\u22D9",
		"gimel": "\u2137",
		"GJcy": "\u0403",
		"gjcy": "\u0453",
		"gla": "\u2AA5",
		"glE": "\u2A92",
		"glj": "\u2AA4",
		"gl": "\u2277",
		"gnapprox": "\u2A8A",
		"gnap": "\u2A8A",
		"gneqq": "\u2269",
		"gneq": "\u2A88",
		"gnE": "\u2269",
		"gne": "\u2A88",
		"gnsim": "\u22E7",
		"Gopf": x"D835DD3E",
		"gopf": x"D835DD58",
		"grave": "\u0060",
		"GreaterEqualLess": "\u22DB",
		"GreaterEqual": "\u2265",
		"GreaterFullEqual": "\u2267",
		"GreaterGreater": "\u2AA2",
		"GreaterLess": "\u2277",
		"GreaterSlantEqual": "\u2A7E",
		"GreaterTilde": "\u2273",
		"gscr": "\u210A",
		"Gscr": x"D835DCA2",
		"gsime": "\u2A8E",
		"gsiml": "\u2A90",
		"gsim": "\u2273",
		"gtcc": "\u2AA7",
		"gtcir": "\u2A7A",
		"gtdot": "\u22D7",
		"gtlPar": "\u2995",
		"gtquest": "\u2A7C",
		"gtrapprox": "\u2A86",
		"gtrarr": "\u2978",
		"gtrdot": "\u22D7",
		"gtreqless": "\u22DB",
		"gtreqqless": "\u2A8C",
		"gtrless": "\u2277",
		"gtrsim": "\u2273",
		"gt": "\u003E",
		"GT": "\u003E",
		"Gt": "\u226B",
		"gvertneqq": x"2269FE00",
		"gvnE": x"2269FE00",
		"Hacek": "\u02C7",
		"hairsp": "\u200A",
		"half": "\u00BD",
		"hamilt": "\u210B",
		"HARDcy": "\u042A",
		"hardcy": "\u044A",
		"harrcir": "\u2948",
		"harr": "\u2194",
		"hArr": "\u21D4",
		"harrw": "\u21AD",
		"Hat": "\u005E",
		"hbar": "\u210F",
		"Hcirc": "\u0124",
		"hcirc": "\u0125",
		"hearts": "\u2665",
		"heartsuit": "\u2665",
		"hellip": "\u2026",
		"hercon": "\u22B9",
		"Hfr": "\u210C",
		"hfr": x"D835DD25",
		"HilbertSpace": "\u210B",
		"hksearow": "\u2925",
		"hkswarow": "\u2926",
		"hoarr": "\u21FF",
		"homtht": "\u223B",
		"hookleftarrow": "\u21A9",
		"hookrightarrow": "\u21AA",
		"Hopf": "\u210D",
		"hopf": x"D835DD59",
		"horbar": "\u2015",
		"HorizontalLine": "\u2500",
		"Hscr": "\u210B",
		"hscr": x"D835DCBD",
		"hslash": "\u210F",
		"Hstrok": "\u0126",
		"hstrok": "\u0127",
		"HumpDownHump": "\u224E",
		"HumpEqual": "\u224F",
		"hybull": "\u2043",
		"hyphen": "\u2010",
		"Iacute": "\u00CD",
		"iacute": "\u00ED",
		"Icirc": "\u00CE",
		"icirc": "\u00EE",
		"ic": "\u2063",
		"Icy": "\u0418",
		"icy": "\u0438",
		"Idot": "\u0130",
		"IEcy": "\u0415",
		"iecy": "\u0435",
		"iexcl": "\u00A1",
		"iff": "\u21D4",
		"Ifr": "\u2111",
		"ifr": x"D835DD26",
		"Igrave": "\u00CC",
		"igrave": "\u00EC",
		"iiiint": "\u2A0C",
		"iiint": "\u222D",
		"iinfin": "\u29DC",
		"iiota": "\u2129",
		"ii": "\u2148",
		"IJlig": "\u0132",
		"ijlig": "\u0133",
		"Imacr": "\u012A",
		"imacr": "\u012B",
		"image": "\u2111",
		"ImaginaryI": "\u2148",
		"imagline": "\u2110",
		"imagpart": "\u2111",
		"imath": "\u0131",
		"imof": "\u22B7",
		"imped": "\u01B5",
		"Implies": "\u21D2",
		"Im": "\u2111",
		"incare": "\u2105",
		"infintie": "\u29DD",
		"infin": "\u221E",
		"inodot": "\u0131",
		"intcal": "\u22BA",
		"integers": "\u2124",
		"Integral": "\u222B",
		"intercal": "\u22BA",
		"Intersection": "\u22C2",
		"intlarhk": "\u2A17",
		"intprod": "\u2A3C",
		"int": "\u222B",
		"Int": "\u222C",
		"in": "\u2208",
		"InvisibleComma": "\u2063",
		"InvisibleTimes": "\u2062",
		"IOcy": "\u0401",
		"iocy": "\u0451",
		"Iogon": "\u012E",
		"iogon": "\u012F",
		"Iopf": x"D835DD40",
		"iopf": x"D835DD5A",
		"Iota": "\u0399",
		"iota": "\u03B9",
		"iprod": "\u2A3C",
		"iquest": "\u00BF",
		"Iscr": "\u2110",
		"iscr": x"D835DCBE",
		"isindot": "\u22F5",
		"isinE": "\u22F9",
		"isins": "\u22F4",
		"isinsv": "\u22F3",
		"isin": "\u2208",
		"isinv": "\u2208",
		"Itilde": "\u0128",
		"itilde": "\u0129",
		"it": "\u2062",
		"Iukcy": "\u0406",
		"iukcy": "\u0456",
		"Iuml": "\u00CF",
		"iuml": "\u00EF",
		"Jcirc": "\u0134",
		"jcirc": "\u0135",
		"Jcy": "\u0419",
		"jcy": "\u0439",
		"Jfr": x"D835DD0D",
		"jfr": x"D835DD27",
		"jmath": "\u0237",
		"Jopf": x"D835DD41",
		"jopf": x"D835DD5B",
		"Jscr": x"D835DCA5",
		"jscr": x"D835DCBF",
		"Jsercy": "\u0408",
		"jsercy": "\u0458",
		"Jukcy": "\u0404",
		"jukcy": "\u0454",
		"Kappa": "\u039A",
		"kappa": "\u03BA",
		"kappav": "\u03F0",
		"Kcedil": "\u0136",
		"kcedil": "\u0137",
		"Kcy": "\u041A",
		"kcy": "\u043A",
		"Kfr": x"D835DD0E",
		"kfr": x"D835DD28",
		"kgreen": "\u0138",
		"KHcy": "\u0425",
		"khcy": "\u0445",
		"KJcy": "\u040C",
		"kjcy": "\u045C",
		"Kopf": x"D835DD42",
		"kopf": x"D835DD5C",
		"Kscr": x"D835DCA6",
		"kscr": x"D835DCC0",
		"lAarr": "\u21DA",
		"Lacute": "\u0139",
		"lacute": "\u013A",
		"laemptyv": "\u29B4",
		"lagran": "\u2112",
		"Lambda": "\u039B",
		"lambda": "\u03BB",
		"langd": "\u2991",
		"langle": "\u27E8",
		"lang": "\u27E8",
		"Lang": "\u27EA",
		"Laplacetrf": "\u2112",
		"lap": "\u2A85",
		"laquo": "\u00AB",
		"larrbfs": "\u291F",
		"larrb": "\u21E4",
		"larrfs": "\u291D",
		"larrhk": "\u21A9",
		"larrlp": "\u21AB",
		"larrpl": "\u2939",
		"larrsim": "\u2973",
		"larrtl": "\u21A2",
		"larr": "\u2190",
		"Larr": "\u219E",
		"lArr": "\u21D0",
		"latail": "\u2919",
		"lAtail": "\u291B",
		"lates": x"2AADFE00",
		"late": "\u2AAD",
		"lat": "\u2AAB",
		"lbarr": "\u290C",
		"lBarr": "\u290E",
		"lbbrk": "\u2772",
		"lbrace": "\u007B",
		"lbrack": "\u005B",
		"lbrke": "\u298B",
		"lbrksld": "\u298F",
		"lbrkslu": "\u298D",
		"Lcaron": "\u013D",
		"lcaron": "\u013E",
		"Lcedil": "\u013B",
		"lcedil": "\u013C",
		"lceil": "\u2308",
		"lcub": "\u007B",
		"Lcy": "\u041B",
		"lcy": "\u043B",
		"ldca": "\u2936",
		"ldquor": "\u201E",
		"ldquo": "\u201C",
		"ldrdhar": "\u2967",
		"ldrushar": "\u294B",
		"ldsh": "\u21B2",
		"LeftAngleBracket": "\u27E8",
		"LeftArrowBar": "\u21E4",
		"LeftArrowRightArrow": "\u21C6",
		"leftarrowtail": "\u21A2",
		"leftarrow": "\u2190",
		"LeftArrow": "\u2190",
		"Leftarrow": "\u21D0",
		"LeftCeiling": "\u2308",
		"LeftDoubleBracket": "\u27E6",
		"LeftDownTeeVector": "\u2961",
		"LeftDownVectorBar": "\u2959",
		"LeftDownVector": "\u21C3",
		"LeftFloor": "\u230A",
		"leftharpoondown": "\u21BD",
		"leftharpoonup": "\u21BC",
		"leftleftarrows": "\u21C7",
		"leftrightarrows": "\u21C6",
		"leftrightarrow": "\u2194",
		"LeftRightArrow": "\u2194",
		"Leftrightarrow": "\u21D4",
		"leftrightharpoons": "\u21CB",
		"leftrightsquigarrow": "\u21AD",
		"LeftRightVector": "\u294E",
		"LeftTeeArrow": "\u21A4",
		"LeftTee": "\u22A3",
		"LeftTeeVector": "\u295A",
		"leftthreetimes": "\u22CB",
		"LeftTriangleBar": "\u29CF",
		"LeftTriangleEqual": "\u22B4",
		"LeftTriangle": "\u22B2",
		"LeftUpDownVector": "\u2951",
		"LeftUpTeeVector": "\u2960",
		"LeftUpVectorBar": "\u2958",
		"LeftUpVector": "\u21BF",
		"LeftVectorBar": "\u2952",
		"LeftVector": "\u21BC",
		"leg": "\u22DA",
		"lEg": "\u2A8B",
		"leqq": "\u2266",
		"leqslant": "\u2A7D",
		"leq": "\u2264",
		"lescc": "\u2AA8",
		"lesdotor": "\u2A83",
		"lesdoto": "\u2A81",
		"lesdot": "\u2A7F",
		"lesges": "\u2A93",
		"lesg": x"22DAFE00",
		"lessapprox": "\u2A85",
		"lessdot": "\u22D6",
		"lesseqgtr": "\u22DA",
		"lesseqqgtr": "\u2A8B",
		"LessEqualGreater": "\u22DA",
		"LessFullEqual": "\u2266",
		"LessGreater": "\u2276",
		"lessgtr": "\u2276",
		"LessLess": "\u2AA1",
		"lesssim": "\u2272",
		"LessSlantEqual": "\u2A7D",
		"LessTilde": "\u2272",
		"les": "\u2A7D",
		"le": "\u2264",
		"lE": "\u2266",
		"lfisht": "\u297C",
		"lfloor": "\u230A",
		"Lfr": x"D835DD0F",
		"lfr": x"D835DD29",
		"lgE": "\u2A91",
		"lg": "\u2276",
		"lhard": "\u21BD",
		"lHar": "\u2962",
		"lharul": "\u296A",
		"lharu": "\u21BC",
		"lhblk": "\u2584",
		"LJcy": "\u0409",
		"ljcy": "\u0459",
		"llarr": "\u21C7",
		"llcorner": "\u231E",
		"Lleftarrow": "\u21DA",
		"llhard": "\u296B",
		"lltri": "\u25FA",
		"ll": "\u226A",
		"Ll": "\u22D8",
		"Lmidot": "\u013F",
		"lmidot": "\u0140",
		"lmoustache": "\u23B0",
		"lmoust": "\u23B0",
		"lnapprox": "\u2A89",
		"lnap": "\u2A89",
		"lneqq": "\u2268",
		"lneq": "\u2A87",
		"lnE": "\u2268",
		"lne": "\u2A87",
		"lnsim": "\u22E6",
		"loang": "\u27EC",
		"loarr": "\u21FD",
		"lobrk": "\u27E6",
		"longleftarrow": "\u27F5",
		"LongLeftArrow": "\u27F5",
		"Longleftarrow": "\u27F8",
		"longleftrightarrow": "\u27F7",
		"LongLeftRightArrow": "\u27F7",
		"Longleftrightarrow": "\u27FA",
		"longmapsto": "\u27FC",
		"longrightarrow": "\u27F6",
		"LongRightArrow": "\u27F6",
		"Longrightarrow": "\u27F9",
		"looparrowleft": "\u21AB",
		"looparrowright": "\u21AC",
		"lopar": "\u2985",
		"Lopf": x"D835DD43",
		"lopf": x"D835DD5D",
		"loplus": "\u2A2D",
		"lotimes": "\u2A34",
		"lowast": "\u2217",
		"lowbar": "\u005F",
		"LowerLeftArrow": "\u2199",
		"LowerRightArrow": "\u2198",
		"lozenge": "\u25CA",
		"lozf": "\u29EB",
		"loz": "\u25CA",
		"lparlt": "\u2993",
		"lpar": "\u0028",
		"lrarr": "\u21C6",
		"lrcorner": "\u231F",
		"lrhard": "\u296D",
		"lrhar": "\u21CB",
		"lrm": "\u200E",
		"lrtri": "\u22BF",
		"lsaquo": "\u2039",
		"Lscr": "\u2112",
		"lscr": x"D835DCC1",
		"lsh": "\u21B0",
		"Lsh": "\u21B0",
		"lsime": "\u2A8D",
		"lsimg": "\u2A8F",
		"lsim": "\u2272",
		"lsqb": "\u005B",
		"lsquor": "\u201A",
		"lsquo": "\u2018",
		"Lstrok": "\u0141",
		"lstrok": "\u0142",
		"ltcc": "\u2AA6",
		"ltcir": "\u2A79",
		"ltdot": "\u22D6",
		"lthree": "\u22CB",
		"ltimes": "\u22C9",
		"ltlarr": "\u2976",
		"ltquest": "\u2A7B",
		"ltrie": "\u22B4",
		"ltrif": "\u25C2",
		"ltri": "\u25C3",
		"ltrPar": "\u2996",
		"lt": "\u003C",
		"LT": "\u003C",
		"Lt": "\u226A",
		"lurdshar": "\u294A",
		"luruhar": "\u2966",
		"lvertneqq": x"2268FE00",
		"lvnE": x"2268FE00",
		"macr": "\u00AF",
		"male": "\u2642",
		"maltese": "\u2720",
		"malt": "\u2720",
		"mapstodown": "\u21A7",
		"mapstoleft": "\u21A4",
		"mapsto": "\u21A6",
		"mapstoup": "\u21A5",
		"map": "\u21A6",
		"Map": "\u2905",
		"marker": "\u25AE",
		"mcomma": "\u2A29",
		"Mcy": "\u041C",
		"mcy": "\u043C",
		"mdash": "\u2014",
		"mDDot": "\u223A",
		"measuredangle": "\u2221",
		"MediumSpace": "\u205F",
		"Mellintrf": "\u2133",
		"Mfr": x"D835DD10",
		"mfr": x"D835DD2A",
		"mho": "\u2127",
		"micro": "\u00B5",
		"midast": "\u002A",
		"midcir": "\u2AF0",
		"middot": "\u00B7",
		"mid": "\u2223",
		"minusb": "\u229F",
		"minusd": "\u2238",
		"minusdu": "\u2A2A",
		"MinusPlus": "\u2213",
		"minus": "\u2212",
		"mlcp": "\u2ADB",
		"mldr": "\u2026",
		"mnplus": "\u2213",
		"models": "\u22A7",
		"Mopf": x"D835DD44",
		"mopf": x"D835DD5E",
		"mp": "\u2213",
		"Mscr": "\u2133",
		"mscr": x"D835DCC2",
		"mstpos": "\u223E",
		"multimap": "\u22B8",
		"mumap": "\u22B8",
		"Mu": "\u039C",
		"mu": "\u03BC",
		"nabla": "\u2207",
		"Nacute": "\u0143",
		"nacute": "\u0144",
		"nang": x"222020D2",
		"napE": x"2A700338",
		"napid": x"224B0338",
		"napos": "\u0149",
		"napprox": "\u2249",
		"nap": "\u2249",
		"naturals": "\u2115",
		"natural": "\u266E",
		"natur": "\u266E",
		"nbsp": "\u00A0",
		"nbumpe": x"224F0338",
		"nbump": x"224E0338",
		"ncap": "\u2A43",
		"Ncaron": "\u0147",
		"ncaron": "\u0148",
		"Ncedil": "\u0145",
		"ncedil": "\u0146",
		"ncongdot": x"2A6D0338",
		"ncong": "\u2247",
		"ncup": "\u2A42",
		"Ncy": "\u041D",
		"ncy": "\u043D",
		"ndash": "\u2013",
		"nearhk": "\u2924",
		"nearrow": "\u2197",
		"nearr": "\u2197",
		"neArr": "\u21D7",
		"nedot": x"22500338",
		"NegativeMediumSpace": "\u200B",
		"NegativeThickSpace": "\u200B",
		"NegativeThinSpace": "\u200B",
		"NegativeVeryThinSpace": "\u200B",
		"nequiv": "\u2262",
		"nesear": "\u2928",
		"nesim": x"22420338",
		"NestedGreaterGreater": "\u226B",
		"NestedLessLess": "\u226A",
		"ne": "\u2260",
		"NewLine": "\u000A",
		"nexists": "\u2204",
		"nexist": "\u2204",
		"Nfr": x"D835DD11",
		"nfr": x"D835DD2B",
		"ngeqq": x"22670338",
		"ngeqslant": x"2A7E0338",
		"ngeq": "\u2271",
		"nges": x"2A7E0338",
		"ngE": x"22670338",
		"nge": "\u2271",
		"nGg": x"22D90338",
		"ngsim": "\u2275",
		"ngtr": "\u226F",
		"nGt": x"226B20D2",
		"ngt": "\u226F",
		"nGtv": x"226B0338",
		"nharr": "\u21AE",
		"nhArr": "\u21CE",
		"nhpar": "\u2AF2",
		"nisd": "\u22FA",
		"nis": "\u22FC",
		"ni": "\u220B",
		"niv": "\u220B",
		"NJcy": "\u040A",
		"njcy": "\u045A",
		"nlarr": "\u219A",
		"nlArr": "\u21CD",
		"nldr": "\u2025",
		"nleftarrow": "\u219A",
		"nLeftarrow": "\u21CD",
		"nleftrightarrow": "\u21AE",
		"nLeftrightarrow": "\u21CE",
		"nleqq": x"22660338",
		"nleqslant": x"2A7D0338",
		"nleq": "\u2270",
		"nless": "\u226E",
		"nles": x"2A7D0338",
		"nlE": x"22660338",
		"nle": "\u2270",
		"nLl": x"22D80338",
		"nlsim": "\u2274",
		"nltrie": "\u22EC",
		"nltri": "\u22EA",
		"nLt": x"226A20D2",
		"nlt": "\u226E",
		"nLtv": x"226A0338",
		"nmid": "\u2224",
		"NoBreak": "\u2060",
		"NonBreakingSpace": "\u00A0",
		"Nopf": "\u2115",
		"nopf": x"D835DD5F",
		"NotCongruent": "\u2262",
		"NotCupCap": "\u226D",
		"NotDoubleVerticalBar": "\u2226",
		"NotElement": "\u2209",
		"NotEqualTilde": x"22420338",
		"NotEqual": "\u2260",
		"NotExists": "\u2204",
		"NotGreaterEqual": "\u2271",
		"NotGreaterFullEqual": x"22670338",
		"NotGreaterGreater": x"226B0338",
		"NotGreaterLess": "\u2279",
		"NotGreaterSlantEqual": x"2A7E0338",
		"NotGreaterTilde": "\u2275",
		"NotGreater": "\u226F",
		"NotHumpDownHump": x"224E0338",
		"NotHumpEqual": x"224F0338",
		"notindot": x"22F50338",
		"notinE": x"22F90338",
		"notin": "\u2209",
		"notinva": "\u2209",
		"notinvb": "\u22F7",
		"notinvc": "\u22F6",
		"NotLeftTriangleBar": x"29CF0338",
		"NotLeftTriangleEqual": "\u22EC",
		"NotLeftTriangle": "\u22EA",
		"NotLessEqual": "\u2270",
		"NotLessGreater": "\u2278",
		"NotLessLess": x"226A0338",
		"NotLessSlantEqual": x"2A7D0338",
		"NotLessTilde": "\u2274",
		"NotLess": "\u226E",
		"NotNestedGreaterGreater": x"2AA20338",
		"NotNestedLessLess": x"2AA10338",
		"notni": "\u220C",
		"notniva": "\u220C",
		"notnivb": "\u22FE",
		"notnivc": "\u22FD",
		"NotPrecedesEqual": x"2AAF0338",
		"NotPrecedesSlantEqual": "\u22E0",
		"NotPrecedes": "\u2280",
		"NotReverseElement": "\u220C",
		"NotRightTriangleBar": x"29D00338",
		"NotRightTriangleEqual": "\u22ED",
		"NotRightTriangle": "\u22EB",
		"NotSquareSubsetEqual": "\u22E2",
		"NotSquareSubset": x"228F0338",
		"NotSquareSupersetEqual": "\u22E3",
		"NotSquareSuperset": x"22900338",
		"NotSubsetEqual": "\u2288",
		"NotSubset": x"228220D2",
		"NotSucceedsEqual": x"2AB00338",
		"NotSucceedsSlantEqual": "\u22E1",
		"NotSucceedsTilde": x"227F0338",
		"NotSucceeds": "\u2281",
		"NotSupersetEqual": "\u2289",
		"NotSuperset": x"228320D2",
		"NotTildeEqual": "\u2244",
		"NotTildeFullEqual": "\u2247",
		"NotTildeTilde": "\u2249",
		"NotTilde": "\u2241",
		"not": "\u00AC",
		"Not": "\u2AEC",
		"NotVerticalBar": "\u2224",
		"nparallel": "\u2226",
		"nparsl": x"2AFD20E5",
		"npart": x"22020338",
		"npar": "\u2226",
		"npolint": "\u2A14",
		"nprcue": "\u22E0",
		"npreceq": x"2AAF0338",
		"nprec": "\u2280",
		"npre": x"2AAF0338",
		"npr": "\u2280",
		"nrarrc": x"29330338",
		"nrarr": "\u219B",
		"nrArr": "\u21CF",
		"nrarrw": x"219D0338",
		"nrightarrow": "\u219B",
		"nRightarrow": "\u21CF",
		"nrtrie": "\u22ED",
		"nrtri": "\u22EB",
		"nsccue": "\u22E1",
		"nsce": x"2AB00338",
		"Nscr": x"D835DCA9",
		"nscr": x"D835DCC3",
		"nsc": "\u2281",
		"nshortmid": "\u2224",
		"nshortparallel": "\u2226",
		"nsimeq": "\u2244",
		"nsime": "\u2244",
		"nsim": "\u2241",
		"nsmid": "\u2224",
		"nspar": "\u2226",
		"nsqsube": "\u22E2",
		"nsqsupe": "\u22E3",
		"nsube": "\u2288",
		"nsubE": x"2AC50338",
		"nsubseteqq": x"2AC50338",
		"nsubseteq": "\u2288",
		"nsubset": x"228220D2",
		"nsub": "\u2284",
		"nsucceq": x"2AB00338",
		"nsucc": "\u2281",
		"nsupe": "\u2289",
		"nsupE": x"2AC60338",
		"nsupseteqq": x"2AC60338",
		"nsupseteq": "\u2289",
		"nsupset": x"228320D2",
		"nsup": "\u2285",
		"ntgl": "\u2279",
		"Ntilde": "\u00D1",
		"ntilde": "\u00F1",
		"ntlg": "\u2278",
		"ntrianglelefteq": "\u22EC",
		"ntriangleleft": "\u22EA",
		"ntrianglerighteq": "\u22ED",
		"ntriangleright": "\u22EB",
		"numero": "\u2116",
		"numsp": "\u2007",
		"num": "\u0023",
		"Nu": "\u039D",
		"nu": "\u03BD",
		"nvap": x"224D20D2",
		"nvdash": "\u22AC",
		"nvDash": "\u22AD",
		"nVdash": "\u22AE",
		"nVDash": "\u22AF",
		"nvge": x"226520D2",
		"nvgt": x"003E20D2",
		"nvHarr": "\u2904",
		"nvinfin": "\u29DE",
		"nvlArr": "\u2902",
		"nvle": x"226420D2",
		"nvltrie": x"22B420D2",
		"nvlt": x"003C20D2",
		"nvrArr": "\u2903",
		"nvrtrie": x"22B520D2",
		"nvsim": x"223C20D2",
		"nwarhk": "\u2923",
		"nwarrow": "\u2196",
		"nwarr": "\u2196",
		"nwArr": "\u21D6",
		"nwnear": "\u2927",
		"Oacute": "\u00D3",
		"oacute": "\u00F3",
		"oast": "\u229B",
		"Ocirc": "\u00D4",
		"ocirc": "\u00F4",
		"ocir": "\u229A",
		"Ocy": "\u041E",
		"ocy": "\u043E",
		"odash": "\u229D",
		"Odblac": "\u0150",
		"odblac": "\u0151",
		"odiv": "\u2A38",
		"odot": "\u2299",
		"odsold": "\u29BC",
		"OElig": "\u0152",
		"oelig": "\u0153",
		"ofcir": "\u29BF",
		"Ofr": x"D835DD12",
		"ofr": x"D835DD2C",
		"ogon": "\u02DB",
		"Ograve": "\u00D2",
		"ograve": "\u00F2",
		"ogt": "\u29C1",
		"ohbar": "\u29B5",
		"ohm": "\u03A9",
		"oint": "\u222E",
		"olarr": "\u21BA",
		"olcir": "\u29BE",
		"olcross": "\u29BB",
		"oline": "\u203E",
		"olt": "\u29C0",
		"Omacr": "\u014C",
		"omacr": "\u014D",
		"Omega": "\u03A9",
		"omega": "\u03C9",
		"Omicron": "\u039F",
		"omicron": "\u03BF",
		"omid": "\u29B6",
		"ominus": "\u2296",
		"Oopf": x"D835DD46",
		"oopf": x"D835DD60",
		"opar": "\u29B7",
		"OpenCurlyDoubleQuote": "\u201C",
		"OpenCurlyQuote": "\u2018",
		"operp": "\u29B9",
		"oplus": "\u2295",
		"orarr": "\u21BB",
		"orderof": "\u2134",
		"order": "\u2134",
		"ordf": "\u00AA",
		"ordm": "\u00BA",
		"ord": "\u2A5D",
		"origof": "\u22B6",
		"oror": "\u2A56",
		"orslope": "\u2A57",
		"or": "\u2228",
		"Or": "\u2A54",
		"orv": "\u2A5B",
		"oscr": "\u2134",
		"Oscr": x"D835DCAA",
		"Oslash": "\u00D8",
		"oslash": "\u00F8",
		"osol": "\u2298",
		"oS": "\u24C8",
		"Otilde": "\u00D5",
		"otilde": "\u00F5",
		"otimesas": "\u2A36",
		"otimes": "\u2297",
		"Otimes": "\u2A37",
		"Ouml": "\u00D6",
		"ouml": "\u00F6",
		"ovbar": "\u233D",
		"OverBar": "\u203E",
		"OverBrace": "\u23DE",
		"OverBracket": "\u23B4",
		"OverParenthesis": "\u23DC",
		"parallel": "\u2225",
		"para": "\u00B6",
		"parsim": "\u2AF3",
		"parsl": "\u2AFD",
		"PartialD": "\u2202",
		"part": "\u2202",
		"par": "\u2225",
		"Pcy": "\u041F",
		"pcy": "\u043F",
		"percnt": "\u0025",
		"period": "\u002E",
		"permil": "\u2030",
		"perp": "\u22A5",
		"pertenk": "\u2031",
		"Pfr": x"D835DD13",
		"pfr": x"D835DD2D",
		"Phi": "\u03A6",
		"phi": "\u03C6",
		"phiv": "\u03D5",
		"phmmat": "\u2133",
		"phone": "\u260E",
		"pitchfork": "\u22D4",
		"Pi": "\u03A0",
		"pi": "\u03C0",
		"piv": "\u03D6",
		"planckh": "\u210E",
		"planck": "\u210F",
		"plankv": "\u210F",
		"plusacir": "\u2A23",
		"plusb": "\u229E",
		"pluscir": "\u2A22",
		"plusdo": "\u2214",
		"plusdu": "\u2A25",
		"pluse": "\u2A72",
		"PlusMinus": "\u00B1",
		"plusmn": "\u00B1",
		"plussim": "\u2A26",
		"plustwo": "\u2A27",
		"plus": "\u002B",
		"pm": "\u00B1",
		"Poincareplane": "\u210C",
		"pointint": "\u2A15",
		"Popf": "\u2119",
		"popf": x"D835DD61",
		"pound": "\u00A3",
		"prap": "\u2AB7",
		"prcue": "\u227C",
		"precapprox": "\u2AB7",
		"preccurlyeq": "\u227C",
		"PrecedesEqual": "\u2AAF",
		"PrecedesSlantEqual": "\u227C",
		"PrecedesTilde": "\u227E",
		"Precedes": "\u227A",
		"preceq": "\u2AAF",
		"precnapprox": "\u2AB9",
		"precneqq": "\u2AB5",
		"precnsim": "\u22E8",
		"precsim": "\u227E",
		"prec": "\u227A",
		"pre": "\u2AAF",
		"prE": "\u2AB3",
		"primes": "\u2119",
		"prime": "\u2032",
		"Prime": "\u2033",
		"prnap": "\u2AB9",
		"prnE": "\u2AB5",
		"prnsim": "\u22E8",
		"prod": "\u220F",
		"Product": "\u220F",
		"profalar": "\u232E",
		"profline": "\u2312",
		"profsurf": "\u2313",
		"Proportional": "\u221D",
		"Proportion": "\u2237",
		"propto": "\u221D",
		"prop": "\u221D",
		"prsim": "\u227E",
		"pr": "\u227A",
		"Pr": "\u2ABB",
		"prurel": "\u22B0",
		"Pscr": x"D835DCAB",
		"pscr": x"D835DCC5",
		"Psi": "\u03A8",
		"psi": "\u03C8",
		"puncsp": "\u2008",
		"Qfr": x"D835DD14",
		"qfr": x"D835DD2E",
		"qint": "\u2A0C",
		"Qopf": "\u211A",
		"qopf": x"D835DD62",
		"qprime": "\u2057",
		"Qscr": x"D835DCAC",
		"qscr": x"D835DCC6",
		"quaternions": "\u210D",
		"quatint": "\u2A16",
		"questeq": "\u225F",
		"quest": "\u003F",
		"quot": "\u0022",
		"QUOT": "\u0022",
		"rAarr": "\u21DB",
		"race": x"223D0331",
		"Racute": "\u0154",
		"racute": "\u0155",
		"radic": "\u221A",
		"raemptyv": "\u29B3",
		"rangd": "\u2992",
		"range": "\u29A5",
		"rangle": "\u27E9",
		"rang": "\u27E9",
		"Rang": "\u27EB",
		"raquo": "\u00BB",
		"rarrap": "\u2975",
		"rarrbfs": "\u2920",
		"rarrb": "\u21E5",
		"rarrc": "\u2933",
		"rarrfs": "\u291E",
		"rarrhk": "\u21AA",
		"rarrlp": "\u21AC",
		"rarrpl": "\u2945",
		"rarrsim": "\u2974",
		"rarrtl": "\u21A3",
		"Rarrtl": "\u2916",
		"rarr": "\u2192",
		"Rarr": "\u21A0",
		"rArr": "\u21D2",
		"rarrw": "\u219D",
		"ratail": "\u291A",
		"rAtail": "\u291C",
		"rationals": "\u211A",
		"ratio": "\u2236",
		"rbarr": "\u290D",
		"rBarr": "\u290F",
		"RBarr": "\u2910",
		"rbbrk": "\u2773",
		"rbrace": "\u007D",
		"rbrack": "\u005D",
		"rbrke": "\u298C",
		"rbrksld": "\u298E",
		"rbrkslu": "\u2990",
		"Rcaron": "\u0158",
		"rcaron": "\u0159",
		"Rcedil": "\u0156",
		"rcedil": "\u0157",
		"rceil": "\u2309",
		"rcub": "\u007D",
		"Rcy": "\u0420",
		"rcy": "\u0440",
		"rdca": "\u2937",
		"rdldhar": "\u2969",
		"rdquor": "\u201D",
		"rdquo": "\u201D",
		"rdsh": "\u21B3",
		"realine": "\u211B",
		"realpart": "\u211C",
		"reals": "\u211D",
		"real": "\u211C",
		"rect": "\u25AD",
		"reg": "\u00AE",
		"REG": "\u00AE",
		"Re": "\u211C",
		"ReverseElement": "\u220B",
		"ReverseEquilibrium": "\u21CB",
		"ReverseUpEquilibrium": "\u296F",
		"rfisht": "\u297D",
		"rfloor": "\u230B",
		"Rfr": "\u211C",
		"rfr": x"D835DD2F",
		"rhard": "\u21C1",
		"rHar": "\u2964",
		"rharul": "\u296C",
		"rharu": "\u21C0",
		"Rho": "\u03A1",
		"rho": "\u03C1",
		"rhov": "\u03F1",
		"RightAngleBracket": "\u27E9",
		"RightArrowBar": "\u21E5",
		"RightArrowLeftArrow": "\u21C4",
		"rightarrowtail": "\u21A3",
		"rightarrow": "\u2192",
		"RightArrow": "\u2192",
		"Rightarrow": "\u21D2",
		"RightCeiling": "\u2309",
		"RightDoubleBracket": "\u27E7",
		"RightDownTeeVector": "\u295D",
		"RightDownVectorBar": "\u2955",
		"RightDownVector": "\u21C2",
		"RightFloor": "\u230B",
		"rightharpoondown": "\u21C1",
		"rightharpoonup": "\u21C0",
		"rightleftarrows": "\u21C4",
		"rightleftharpoons": "\u21CC",
		"rightrightarrows": "\u21C9",
		"rightsquigarrow": "\u219D",
		"RightTeeArrow": "\u21A6",
		"RightTee": "\u22A2",
		"RightTeeVector": "\u295B",
		"rightthreetimes": "\u22CC",
		"RightTriangleBar": "\u29D0",
		"RightTriangleEqual": "\u22B5",
		"RightTriangle": "\u22B3",
		"RightUpDownVector": "\u294F",
		"RightUpTeeVector": "\u295C",
		"RightUpVectorBar": "\u2954",
		"RightUpVector": "\u21BE",
		"RightVectorBar": "\u2953",
		"RightVector": "\u21C0",
		"ring": "\u02DA",
		"risingdotseq": "\u2253",
		"rlarr": "\u21C4",
		"rlhar": "\u21CC",
		"rlm": "\u200F",
		"rmoustache": "\u23B1",
		"rmoust": "\u23B1",
		"rnmid": "\u2AEE",
		"roang": "\u27ED",
		"roarr": "\u21FE",
		"robrk": "\u27E7",
		"ropar": "\u2986",
		"Ropf": "\u211D",
		"ropf": x"D835DD63",
		"roplus": "\u2A2E",
		"rotimes": "\u2A35",
		"RoundImplies": "\u2970",
		"rpargt": "\u2994",
		"rpar": "\u0029",
		"rppolint": "\u2A12",
		"rrarr": "\u21C9",
		"Rrightarrow": "\u21DB",
		"rsaquo": "\u203A",
		"Rscr": "\u211B",
		"rscr": x"D835DCC7",
		"rsh": "\u21B1",
		"Rsh": "\u21B1",
		"rsqb": "\u005D",
		"rsquor": "\u2019",
		"rsquo": "\u2019",
		"rthree": "\u22CC",
		"rtimes": "\u22CA",
		"rtrie": "\u22B5",
		"rtrif": "\u25B8",
		"rtriltri": "\u29CE",
		"rtri": "\u25B9",
		"RuleDelayed": "\u29F4",
		"ruluhar": "\u2968",
		"rx": "\u211E",
		"Sacute": "\u015A",
		"sacute": "\u015B",
		"sbquo": "\u201A",
		"scap": "\u2AB8",
		"Scaron": "\u0160",
		"scaron": "\u0161",
		"sccue": "\u227D",
		"Scedil": "\u015E",
		"scedil": "\u015F",
		"sce": "\u2AB0",
		"scE": "\u2AB4",
		"Scirc": "\u015C",
		"scirc": "\u015D",
		"scnap": "\u2ABA",
		"scnE": "\u2AB6",
		"scnsim": "\u22E9",
		"scpolint": "\u2A13",
		"scsim": "\u227F",
		"sc": "\u227B",
		"Sc": "\u2ABC",
		"Scy": "\u0421",
		"scy": "\u0441",
		"sdotb": "\u22A1",
		"sdote": "\u2A66",
		"sdot": "\u22C5",
		"searhk": "\u2925",
		"searrow": "\u2198",
		"searr": "\u2198",
		"seArr": "\u21D8",
		"sect": "\u00A7",
		"semi": "\u003B",
		"seswar": "\u2929",
		"setminus": "\u2216",
		"setmn": "\u2216",
		"sext": "\u2736",
		"sfrown": "\u2322",
		"Sfr": x"D835DD16",
		"sfr": x"D835DD30",
		"sharp": "\u266F",
		"SHCHcy": "\u0429",
		"shchcy": "\u0449",
		"SHcy": "\u0428",
		"shcy": "\u0448",
		"ShortDownArrow": "\u2193",
		"ShortLeftArrow": "\u2190",
		"shortmid": "\u2223",
		"shortparallel": "\u2225",
		"ShortRightArrow": "\u2192",
		"ShortUpArrow": "\u2191",
		"shy": "\u00AD",
		"sigmaf": "\u03C2",
		"Sigma": "\u03A3",
		"sigma": "\u03C3",
		"sigmav": "\u03C2",
		"simdot": "\u2A6A",
		"simeq": "\u2243",
		"sime": "\u2243",
		"simgE": "\u2AA0",
		"simg": "\u2A9E",
		"simlE": "\u2A9F",
		"siml": "\u2A9D",
		"simne": "\u2246",
		"simplus": "\u2A24",
		"simrarr": "\u2972",
		"sim": "\u223C",
		"slarr": "\u2190",
		"SmallCircle": "\u2218",
		"smallsetminus": "\u2216",
		"smashp": "\u2A33",
		"smeparsl": "\u29E4",
		"smid": "\u2223",
		"smile": "\u2323",
		"smtes": x"2AACFE00",
		"smte": "\u2AAC",
		"smt": "\u2AAA",
		"SOFTcy": "\u042C",
		"softcy": "\u044C",
		"solbar": "\u233F",
		"solb": "\u29C4",
		"sol": "\u002F",
		"Sopf": x"D835DD4A",
		"sopf": x"D835DD64",
		"spades": "\u2660",
		"spadesuit": "\u2660",
		"spar": "\u2225",
		"sqcaps": x"2293FE00",
		"sqcap": "\u2293",
		"sqcups": x"2294FE00",
		"sqcup": "\u2294",
		"Sqrt": "\u221A",
		"sqsube": "\u2291",
		"sqsubseteq": "\u2291",
		"sqsubset": "\u228F",
		"sqsub": "\u228F",
		"sqsupe": "\u2292",
		"sqsupseteq": "\u2292",
		"sqsupset": "\u2290",
		"sqsup": "\u2290",
		"SquareIntersection": "\u2293",
		"SquareSubsetEqual": "\u2291",
		"SquareSubset": "\u228F",
		"SquareSupersetEqual": "\u2292",
		"SquareSuperset": "\u2290",
		"square": "\u25A1",
		"Square": "\u25A1",
		"SquareUnion": "\u2294",
		"squarf": "\u25AA",
		"squf": "\u25AA",
		"squ": "\u25A1",
		"srarr": "\u2192",
		"Sscr": x"D835DCAE",
		"sscr": x"D835DCC8",
		"ssetmn": "\u2216",
		"ssmile": "\u2323",
		"sstarf": "\u22C6",
		"starf": "\u2605",
		"Star": "\u22C6",
		"star": "\u2606",
		"straightepsilon": "\u03F5",
		"straightphi": "\u03D5",
		"strns": "\u00AF",
		"subdot": "\u2ABD",
		"subedot": "\u2AC3",
		"sube": "\u2286",
		"subE": "\u2AC5",
		"submult": "\u2AC1",
		"subne": "\u228A",
		"subnE": "\u2ACB",
		"subplus": "\u2ABF",
		"subrarr": "\u2979",
		"subseteqq": "\u2AC5",
		"subseteq": "\u2286",
		"SubsetEqual": "\u2286",
		"subsetneqq": "\u2ACB",
		"subsetneq": "\u228A",
		"subset": "\u2282",
		"Subset": "\u22D0",
		"subsim": "\u2AC7",
		"subsub": "\u2AD5",
		"subsup": "\u2AD3",
		"sub": "\u2282",
		"Sub": "\u22D0",
		"succapprox": "\u2AB8",
		"succcurlyeq": "\u227D",
		"SucceedsEqual": "\u2AB0",
		"SucceedsSlantEqual": "\u227D",
		"SucceedsTilde": "\u227F",
		"Succeeds": "\u227B",
		"succeq": "\u2AB0",
		"succnapprox": "\u2ABA",
		"succneqq": "\u2AB6",
		"succnsim": "\u22E9",
		"succsim": "\u227F",
		"succ": "\u227B",
		"SuchThat": "\u220B",
		"sum": "\u2211",
		"Sum": "\u2211",
		"sung": "\u266A",
		"sup1": "\u00B9",
		"sup2": "\u00B2",
		"sup3": "\u00B3",
		"supdot": "\u2ABE",
		"supdsub": "\u2AD8",
		"supedot": "\u2AC4",
		"SupersetEqual": "\u2287",
		"Superset": "\u2283",
		"supe": "\u2287",
		"supE": "\u2AC6",
		"suphsol": "\u27C9",
		"suphsub": "\u2AD7",
		"suplarr": "\u297B",
		"supmult": "\u2AC2",
		"supne": "\u228B",
		"supnE": "\u2ACC",
		"supplus": "\u2AC0",
		"supseteqq": "\u2AC6",
		"supseteq": "\u2287",
		"supsetneqq": "\u2ACC",
		"supsetneq": "\u228B",
		"supset": "\u2283",
		"Supset": "\u22D1",
		"supsim": "\u2AC8",
		"supsub": "\u2AD4",
		"supsup": "\u2AD6",
		"sup": "\u2283",
		"Sup": "\u22D1",
		"swarhk": "\u2926",
		"swarrow": "\u2199",
		"swarr": "\u2199",
		"swArr": "\u21D9",
		"swnwar": "\u292A",
		"szlig": "\u00DF",
		"Tab": "\u0009",
		"target": "\u2316",
		"Tau": "\u03A4",
		"tau": "\u03C4",
		"tbrk": "\u23B4",
		"Tcaron": "\u0164",
		"tcaron": "\u0165",
		"Tcedil": "\u0162",
		"tcedil": "\u0163",
		"Tcy": "\u0422",
		"tcy": "\u0442",
		"tdot": "\u20DB",
		"telrec": "\u2315",
		"Tfr": x"D835DD17",
		"tfr": x"D835DD31",
		"there4": "\u2234",
		"therefore": "\u2234",
		"Therefore": "\u2234",
		"thetasym": "\u03D1",
		"Theta": "\u0398",
		"theta": "\u03B8",
		"thetav": "\u03D1",
		"thickapprox": "\u2248",
		"thicksim": "\u223C",
		"ThickSpace": x"205F200A",
		"ThinSpace": "\u2009",
		"thinsp": "\u2009",
		"thkap": "\u2248",
		"thksim": "\u223C",
		"THORN": "\u00DE",
		"thorn": "\u00FE",
		"TildeEqual": "\u2243",
		"TildeFullEqual": "\u2245",
		"TildeTilde": "\u2248",
		"tilde": "\u02DC",
		"Tilde": "\u223C",
		"timesbar": "\u2A31",
		"timesb": "\u22A0",
		"timesd": "\u2A30",
		"times": "\u00D7",
		"tint": "\u222D",
		"toea": "\u2928",
		"topbot": "\u2336",
		"topcir": "\u2AF1",
		"topfork": "\u2ADA",
		"Topf": x"D835DD4B",
		"topf": x"D835DD65",
		"top": "\u22A4",
		"tosa": "\u2929",
		"tprime": "\u2034",
		"trade": "\u2122",
		"TRADE": "\u2122",
		"triangledown": "\u25BF",
		"trianglelefteq": "\u22B4",
		"triangleleft": "\u25C3",
		"triangleq": "\u225C",
		"trianglerighteq": "\u22B5",
		"triangleright": "\u25B9",
		"triangle": "\u25B5",
		"tridot": "\u25EC",
		"trie": "\u225C",
		"triminus": "\u2A3A",
		"TripleDot": "\u20DB",
		"triplus": "\u2A39",
		"trisb": "\u29CD",
		"tritime": "\u2A3B",
		"trpezium": "\u23E2",
		"Tscr": x"D835DCAF",
		"tscr": x"D835DCC9",
		"TScy": "\u0426",
		"tscy": "\u0446",
		"TSHcy": "\u040B",
		"tshcy": "\u045B",
		"Tstrok": "\u0166",
		"tstrok": "\u0167",
		"twixt": "\u226C",
		"twoheadleftarrow": "\u219E",
		"twoheadrightarrow": "\u21A0",
		"Uacute": "\u00DA",
		"uacute": "\u00FA",
		"Uarrocir": "\u2949",
		"uarr": "\u2191",
		"Uarr": "\u219F",
		"uArr": "\u21D1",
		"Ubrcy": "\u040E",
		"ubrcy": "\u045E",
		"Ubreve": "\u016C",
		"ubreve": "\u016D",
		"Ucirc": "\u00DB",
		"ucirc": "\u00FB",
		"Ucy": "\u0423",
		"ucy": "\u0443",
		"udarr": "\u21C5",
		"Udblac": "\u0170",
		"udblac": "\u0171",
		"udhar": "\u296E",
		"ufisht": "\u297E",
		"Ufr": x"D835DD18",
		"ufr": x"D835DD32",
		"Ugrave": "\u00D9",
		"ugrave": "\u00F9",
		"uharl": "\u21BF",
		"uharr": "\u21BE",
		"uHar": "\u2963",
		"uhblk": "\u2580",
		"ulcorner": "\u231C",
		"ulcorn": "\u231C",
		"ulcrop": "\u230F",
		"ultri": "\u25F8",
		"Umacr": "\u016A",
		"umacr": "\u016B",
		"uml": "\u00A8",
		"UnderBar": "\u005F",
		"UnderBrace": "\u23DF",
		"UnderBracket": "\u23B5",
		"UnderParenthesis": "\u23DD",
		"UnionPlus": "\u228E",
		"Union": "\u22C3",
		"Uogon": "\u0172",
		"uogon": "\u0173",
		"Uopf": x"D835DD4C",
		"uopf": x"D835DD66",
		"UpArrowBar": "\u2912",
		"UpArrowDownArrow": "\u21C5",
		"uparrow": "\u2191",
		"UpArrow": "\u2191",
		"Uparrow": "\u21D1",
		"updownarrow": "\u2195",
		"UpDownArrow": "\u2195",
		"Updownarrow": "\u21D5",
		"UpEquilibrium": "\u296E",
		"upharpoonleft": "\u21BF",
		"upharpoonright": "\u21BE",
		"uplus": "\u228E",
		"UpperLeftArrow": "\u2196",
		"UpperRightArrow": "\u2197",
		"upsih": "\u03D2",
		"Upsilon": "\u03A5",
		"upsilon": "\u03C5",
		"upsi": "\u03C5",
		"Upsi": "\u03D2",
		"UpTeeArrow": "\u21A5",
		"UpTee": "\u22A5",
		"upuparrows": "\u21C8",
		"urcorner": "\u231D",
		"urcorn": "\u231D",
		"urcrop": "\u230E",
		"Uring": "\u016E",
		"uring": "\u016F",
		"urtri": "\u25F9",
		"Uscr": x"D835DCB0",
		"uscr": x"D835DCCA",
		"utdot": "\u22F0",
		"Utilde": "\u0168",
		"utilde": "\u0169",
		"utrif": "\u25B4",
		"utri": "\u25B5",
		"uuarr": "\u21C8",
		"Uuml": "\u00DC",
		"uuml": "\u00FC",
		"uwangle": "\u29A7",
		"vangrt": "\u299C",
		"varepsilon": "\u03F5",
		"varkappa": "\u03F0",
		"varnothing": "\u2205",
		"varphi": "\u03D5",
		"varpi": "\u03D6",
		"varpropto": "\u221D",
		"varrho": "\u03F1",
		"varr": "\u2195",
		"vArr": "\u21D5",
		"varsigma": "\u03C2",
		"varsubsetneqq": x"2ACBFE00",
		"varsubsetneq": x"228AFE00",
		"varsupsetneqq": x"2ACCFE00",
		"varsupsetneq": x"228BFE00",
		"vartheta": "\u03D1",
		"vartriangleleft": "\u22B2",
		"vartriangleright": "\u22B3",
		"vBar": "\u2AE8",
		"Vbar": "\u2AEB",
		"vBarv": "\u2AE9",
		"Vcy": "\u0412",
		"vcy": "\u0432",
		"Vdashl": "\u2AE6",
		"vdash": "\u22A2",
		"vDash": "\u22A8",
		"Vdash": "\u22A9",
		"VDash": "\u22AB",
		"veebar": "\u22BB",
		"veeeq": "\u225A",
		"vee": "\u2228",
		"Vee": "\u22C1",
		"vellip": "\u22EE",
		"verbar": "\u007C",
		"Verbar": "\u2016",
		"VerticalBar": "\u2223",
		"VerticalLine": "\u007C",
		"VerticalSeparator": "\u2758",
		"VerticalTilde": "\u2240",
		"vert": "\u007C",
		"Vert": "\u2016",
		"VeryThinSpace": "\u200A",
		"Vfr": x"D835DD19",
		"vfr": x"D835DD33",
		"vltri": "\u22B2",
		"vnsub": x"228220D2",
		"vnsup": x"228320D2",
		"Vopf": x"D835DD4D",
		"vopf": x"D835DD67",
		"vprop": "\u221D",
		"vrtri": "\u22B3",
		"Vscr": x"D835DCB1",
		"vscr": x"D835DCCB",
		"vsubne": x"228AFE00",
		"vsubnE": x"2ACBFE00",
		"vsupne": x"228BFE00",
		"vsupnE": x"2ACCFE00",
		"Vvdash": "\u22AA",
		"vzigzag": "\u299A",
		"Wcirc": "\u0174",
		"wcirc": "\u0175",
		"wedbar": "\u2A5F",
		"wedgeq": "\u2259",
		"wedge": "\u2227",
		"Wedge": "\u22C0",
		"weierp": "\u2118",
		"Wfr": x"D835DD1A",
		"wfr": x"D835DD34",
		"Wopf": x"D835DD4E",
		"wopf": x"D835DD68",
		"wp": "\u2118",
		"wreath": "\u2240",
		"wr": "\u2240",
		"Wscr": x"D835DCB2",
		"wscr": x"D835DCCC",
		"xcap": "\u22C2",
		"xcirc": "\u25EF",
		"xcup": "\u22C3",
		"xdtri": "\u25BD",
		"Xfr": x"D835DD1B",
		"xfr": x"D835DD35",
		"xharr": "\u27F7",
		"xhArr": "\u27FA",
		"Xi": "\u039E",
		"xi": "\u03BE",
		"xlarr": "\u27F5",
		"xlArr": "\u27F8",
		"xmap": "\u27FC",
		"xnis": "\u22FB",
		"xodot": "\u2A00",
		"Xopf": x"D835DD4F",
		"xopf": x"D835DD69",
		"xoplus": "\u2A01",
		"xotime": "\u2A02",
		"xrarr": "\u27F6",
		"xrArr": "\u27F9",
		"Xscr": x"D835DCB3",
		"xscr": x"D835DCCD",
		"xsqcup": "\u2A06",
		"xuplus": "\u2A04",
		"xutri": "\u25B3",
		"xvee": "\u22C1",
		"xwedge": "\u22C0",
		"Yacute": "\u00DD",
		"yacute": "\u00FD",
		"YAcy": "\u042F",
		"yacy": "\u044F",
		"Ycirc": "\u0176",
		"ycirc": "\u0177",
		"Ycy": "\u042B",
		"ycy": "\u044B",
		"yen": "\u00A5",
		"Yfr": x"D835DD1C",
		"yfr": x"D835DD36",
		"YIcy": "\u0407",
		"yicy": "\u0457",
		"Yopf": x"D835DD50",
		"yopf": x"D835DD6A",
		"Yscr": x"D835DCB4",
		"yscr": x"D835DCCE",
		"YUcy": "\u042E",
		"yucy": "\u044E",
		"yuml": "\u00FF",
		"Yuml": "\u0178",
		"Zacute": "\u0179",
		"zacute": "\u017A",
		"Zcaron": "\u017D",
		"zcaron": "\u017E",
		"Zcy": "\u0417",
		"zcy": "\u0437",
		"Zdot": "\u017B",
		"zdot": "\u017C",
		"zeetrf": "\u2128",
		"ZeroWidthSpace": "\u200B",
		"Zeta": "\u0396",
		"zeta": "\u03B6",
		"Zfr": "\u2128",
		"zfr": x"D835DD37",
		"ZHcy": "\u0416",
		"zhcy": "\u0436",
		"zigrarr": "\u21DD",
		"Zopf": "\u2124",
		"zopf": x"D835DD6B",
		"Zscr": x"D835DCB5",
		"zscr": x"D835DCCF",
		"zwj": "\u200D",
		"zwnj": "\u200C"
	];
}
